package com.dgtly.sync.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.dgtly.common.exception.BusinessException;
import com.dgtly.common.utils.ShiroSaltUtil;
import com.dgtly.common.utils.security.EncryptPassWordClass;
import com.dgtly.sync.domain.MetaDiySalesorgtree;
import com.dgtly.sync.domain.MetaEmployeeDiy;
import com.dgtly.sync.domain.SyncFailDetail;
import com.dgtly.sync.domain.SyncLog;
import com.dgtly.sync.exception.NotFountOrgCodeException;
import com.dgtly.sync.exception.OutOfDIYPostNameException;
import com.dgtly.sync.exception.OutOfLeveLException;
import com.dgtly.sync.exception.OutOfScopeDIYException;
import com.dgtly.sync.mapper.MetaDiySalesorgtreeMapper;
import com.dgtly.sync.mapper.MetaEmployeeDiyMapper;
import com.dgtly.sync.mapper.SyncFailDetailMapper;
import com.dgtly.sync.service.IAnalysisSysUserService;
import com.dgtly.sync.service.ISyncLogService;
import com.dgtly.system.domain.SysDictData;
import com.dgtly.system.domain.SysUser;
import com.dgtly.system.domain.SysUserExt;
import com.dgtly.system.service.ISysConfigService;
import com.dgtly.system.service.ISysDictDataService;
import com.dgtly.system.service.ISysUserService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import java.util.*;

@Service("analysisDiyCustomerService")
public class AnalysisSysUserService implements IAnalysisSysUserService {

    private static final Logger log = LoggerFactory.getLogger(AnalysisSysUserService.class);




    @Autowired
    private SyncFailDetailMapper syncFailDetailMapper;
    @Autowired
    private ISysConfigService configService;
    @Autowired
    private ISysDictDataService sysDictDataService;

    @Autowired
    private ISysUserService sysUserService;
    @Autowired
    private MetaEmployeeDiyMapper metaEmployeeDiyMapper;
    @Autowired
    private MetaDiySalesorgtreeMapper metaDiySalesorgtreeMapper;
    @Autowired
    private ISyncLogService syncLogService;



    /**
     * 解析DIY用户数据  异步执行
     * @param packageId
     * @return
     */
    @Override
    @Async
    public SyncLog analysisSysUser(String packageId){
        MetaEmployeeDiy param = new MetaEmployeeDiy();
        if(packageId==null||packageId.trim().equals("")){
            Long l = new Date().getTime();
            packageId = l.toString();
        }else{
            param.setPackageId(packageId);
        }
        List<MetaEmployeeDiy> metaEmployeeDiys = metaEmployeeDiyMapper.selectMetaEmployeeDiyList(param);
        SyncLog syncLog = new SyncLog();
        syncLog.setSyncType("sysuser");
        syncLog.setStartTime(new Date());

        Set<String> loginNameList = sysUserService.selectAllUserLoginName();


        syncLog.setPackageId(packageId);
        syncLog.setTotalCount((long)metaEmployeeDiys.size());
        List<SyncFailDetail> failDetails = new ArrayList<>();
        long successCount = 0;
        long failCount = 0;

        Long deptId = Long.parseLong(configService.selectConfigByKey("libang.user.deptid"));
        Long roleId = Long.parseLong(configService.selectConfigByKey("libang.user.roleid"));
        Long[] roleIds = {roleId};
        if(metaEmployeeDiys.size()>0){

            //用户objid3为列表内的内容才为DIY人员
            Set<String> diyObjid3Set =  getConfigValueSet("libang_diyobjid3");
            //用户岗位名称为列表的内容才是区公司级别人员
            Set<String> companySet =  getConfigValueSet("libang_company_level_postname");
            //用户岗位名称为列表的内容才是销售大区级别人员
            Set<String> saledeptSet =  getConfigValueSet("libang_saledept_level_postname");
            //用户岗位名称为列表的内容才是销售部级别人员
            Set<String> officeSet =  getConfigValueSet("libang_office_level_postname");
            //用户岗位名称为列表的内容才是销售分部级别人员
            Set<String> subofficeSet =  getConfigValueSet("libang_suboffice_level_postname");
            //用户岗位名称为列表的内容才是销售员级别人员
            Set<String> empSet =  getConfigValueSet("libang_emp_level_postname");
            Map<Integer,Map<String,Map<String,String>>>  salesTreeMap = getDiySalesOrgTree();



            for(MetaEmployeeDiy m:metaEmployeeDiys) {
                try {
                    //用户是否属于DIY筛选范围
//                    if(!diyObjid3Set.contains(m.getStext3())){
//                        throw new OutOfScopeDIYException(m);
//                    }
                    /** =============用户基本信息构建 start===============*/
                    SysUser user = new SysUser();
                    user.setCompanyId(1L);
                    user.setDeptId(deptId);
                    user.setLoginName(m.getLoginName());
                    user.setUserName(m.getName());
                    user.setEmail(m.getEmail());
                    user.setPhonenumber(m.getMobile());
                    String sex = ""+(Integer.parseInt(m.getSex())-1);
                    user.setSex(sex);
                    user.setRoleIds(roleIds);
                    if (m.getStatus() == 0) {
                        user.setStatus("1");
                        user.setDelFlag("2");
                    } else {
                        user.setStatus("0");
                    }
                    /** =============用户基本信息构建 end===============*/



                    /**======== 构建diy用户扩展信息表 start===============*/
                    SysUserExt userExt = new SysUserExt();
                    userExt.setBossEmployeeId(m.getBossEmployeeId());
                    userExt.setBossName(m.getBossName());
                    userExt.setSapEmployeeId(m.getSapEmployeeId());
                    userExt.setPostCode(m.getEmployeePost());
                    userExt.setPostName(m.getEmployeePostName());
                    //判断用户所处销售层级

                    String fildName ="";
                    String fildCode = "";
                    if(m.getStext6()!=null){
                        if(empSet.contains(m.getEmployeePostName())){
                            userExt.setSalesLevel("emp_level");
                            userExt.setOrgName(m.getStext6());
                            setExtOrgCode(salesTreeMap,6,userExt);
                            fildName = "Org6name";
                            fildCode = "Org6code";
                        }else if(subofficeSet.contains(m.getEmployeePostName())){
                            userExt.setSalesLevel("suboffice_level");
                            userExt.setOrgName(m.getStext6());
                            setExtOrgCode(salesTreeMap,6,userExt);
                            fildName = "Org6name";
                            fildCode = "Org6code";
                        }else{
                            throw new OutOfDIYPostNameException(m,6);
                        }
                    }else if(m.getStext5()!=null){

                        if(officeSet.contains(m.getEmployeePostName())){
                            userExt.setSalesLevel("office_level");
                            userExt.setOrgName(m.getStext5());
                            setExtOrgCode(salesTreeMap,5,userExt);
                            fildName = "Org5name";
                            fildCode = "Org5code";
                        }else{
                            throw new OutOfDIYPostNameException(m,5);
                        }
                    }else if(m.getStext4()!=null){
                        if(saledeptSet.contains(m.getEmployeePostName())){
                            userExt.setSalesLevel("saledept_level");
                            userExt.setOrgName(m.getStext4());
                            setExtOrgCode(salesTreeMap,4,userExt);
                            fildName = "Org4name";
                            fildCode = "Org4code";
                        } else{
                            throw new OutOfDIYPostNameException(m,4);
                        }
                    }else if(m.getStext3()!=null){
                        if(companySet.contains(m.getEmployeePostName())){
                            userExt.setSalesLevel("company_level");
                            userExt.setOrgName(m.getStext3());
                            setExtOrgCode(salesTreeMap,3,userExt);
                            fildName = "Org3name";
                            fildCode = "Org3code";
                        } else{
                            throw new OutOfDIYPostNameException(m,3);
                        }
                    }else{
                        throw new OutOfLeveLException(m);
                    }



//                    if(userExt.getOrgName()!=null){
//                        Map<String,String> map=  metaDiySalesorgtreeMapper.selectSalesorgByName(fildName,fildCode,userExt.getOrgName());
//                        if(map!=null && map.containsKey("orgcode")){
//                            userExt.setOrgCode(map.get("orgcode"));
//                        }
//                    }
                    if(userExt.getOrgCode()==null){
                        throw new NotFountOrgCodeException(m);
                    }
                    /**======== 构建diy用户扩展信息表 end===============*/



                    if (loginNameList.contains(user.getLoginName())) {
                        /**  更新 */
                        SysUser userInDb =sysUserService.selectUserByLoginName(user.getLoginName());
                        if(!userInDb.getSysUserExt().getSalesLevel().equals("diy_level")){
                            user.setSysUserExt(userExt);
                        }
                        sysUserService.updateUserInfoAndSalesExt(user);
                    } else {
                        /**  插入 */
                        //修改密码并加密
                        user.setPassword(m.getLoginName());
                        user.setSalt(ShiroSaltUtil.randomSalt());
                        user.setPassword(EncryptPassWordClass.encryptPassword(user.getLoginName(), user.getPassword(), user.getSalt()));
                        user.setSysUserExt(userExt);
                        sysUserService.insertUserAndSalesExt(user);
                        successCount++;
                    }
                }catch (OutOfScopeDIYException|NotFountOrgCodeException|OutOfDIYPostNameException|OutOfLeveLException e){
                    /**
                     * 警告类异常
                     */
                    SyncFailDetail syncFailDetail = new SyncFailDetail();
                    syncFailDetail.setPackageId(packageId);
                    syncFailDetail.setFailReason(e.getMessage());
                    syncFailDetail.setDataJson(JSONObject.toJSONString(m));
                    syncFailDetail.setFailLevel("0");
                    syncFailDetail.setExceptionType(e.getClass().getSimpleName());
                    failDetails.add(syncFailDetail);
                    failCount++;
                }catch (Exception e) {
                    /**
                     * 错误异常
                     */
                    SyncFailDetail syncFailDetail = new SyncFailDetail();
                    syncFailDetail.setPackageId(packageId);
                    syncFailDetail.setFailReason(e.getMessage());
                    syncFailDetail.setDataJson(JSONObject.toJSONString(m));
                    syncFailDetail.setFailLevel("1");
                    syncFailDetail.setExceptionType(e.getClass().getSimpleName());
                    failDetails.add(syncFailDetail);
                    e.printStackTrace();
                    log.error("解析用户出错", e);
                    failCount++;
                }
            }
            syncLog.setSuccessCount(successCount);
            syncLog.setFaileCount(failCount);
        }else{
            syncLog.setSuccessCount(0l);
            syncLog.setFaileCount(0l);
        }
        try{
            syncLog.setEndTime(new Date());
            if(failDetails.size()>0){
                syncFailDetailMapper.batchInsertSyncFailDetail(failDetails);
            }
        }catch (Exception e){
            log.error("解析用户插入解析日志出错",e);
            e.printStackTrace();
            throw new BusinessException("解析用户插入解析日志出错",e);
        }finally {
            syncLogService.insertSyncLog(syncLog);
        }
        return syncLog;

    }

    /**
     * 获取字典的set
     * @param dictType
     * @return
     */
    public Set<String> getConfigValueSet(String dictType){
        Set<String> res = new HashSet<>();
        List<SysDictData> dictDatas = sysDictDataService.selectSimpleDictDataByType(dictType);
        for(SysDictData d: dictDatas){
            res.add(d.getDictValue());
        }
        return res;
    }


    /**
     * 获取销售组织架构树
     * @return
     */
    public Map<Integer,Map<String,Map<String,String>>> getDiySalesOrgTree(){
        Map<String,Map<String,String>> map3= metaDiySalesorgtreeMapper.selectSalesTreeByLevel(3);
        Map<String,Map<String,String>> map4= metaDiySalesorgtreeMapper.selectSalesTreeByLevel(4);
        Map<String,Map<String,String>> map5= metaDiySalesorgtreeMapper.selectSalesTreeByLevel(5);
        Map<String,Map<String,String>> map6= metaDiySalesorgtreeMapper.selectSalesTreeByLevel(6);
        Map<Integer,Map<String,Map<String,String>>>res = new HashMap<>();
        res.put(3,map3);
        res.put(4,map4);
        res.put(5,map5);
        res.put(6,map6);
        return res;
    }

    /**
     * 根据销售的部门等级及销售组织名称获取销售的组织code
     * @param salesTree
     * @param level 销售登记
     * @param userExt 用户扩展信息
     * @return
     */
    public boolean setExtOrgCode(Map<Integer,Map<String,Map<String,String>>> salesTree,int level,SysUserExt userExt){
        if(userExt.getOrgName()==null||userExt.getOrgName().trim().equals("")){
            return false;
        }
        String orgname = userExt.getOrgName();
        for(;level<7;level++){
            if(salesTree.containsKey(level)){
                Map<String,Map<String,String>> temp = salesTree.get(level);
                if(temp.containsKey(orgname)){
                    userExt.setOrgCode(temp.get(orgname).get("orgcode"));
                    return true;
                }else{
                    continue;
                }
            }
        }
        return false;

    }



}
