package com.dgtly.sync.utils;

import com.alibaba.fastjson.JSONObject;
import com.dgtly.common.exception.BusinessException;
import com.dgtly.common.utils.http.HttpUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import java.util.Date;

@Component
public class CustomerAccessTokenUtil {
    public enum UrlType{

        MANAGER,
        STOREGUIDE;



    }

    private static final Logger log = LoggerFactory.getLogger(CustomerAccessTokenUtil.class);

    private String accessToken;
    /**
     * 创建时间
     */
    private long createTime;

    /**
     * 过期时间单位s
     */
    private long expires;


    @Value(value = "${customer.appid:none}")
    private String appid;



    @Value(value = "${customer.appsecret:none}")
    private String appsecret;

    @Value(value = "${customer.domain:none}")
    private String domain;

    //获取token地址
    private String tokenUrl;
    //获取经销商负责人列表
    private String managerListUrl ;
    //获取经销商导购列表
    private String storeGuideListUrl ;

    @PostConstruct
    public void init() {
        tokenUrl=domain+"/auth/jwt/v1/gettoken?appid=%s&appsecret=%s";
        managerListUrl =domain+"/wechatwork/diydt/v1/user/manager/list?access_token=%s";
        storeGuideListUrl =domain+"/wechatwork/diydt/v1/user/storeGuide/list?access_token=%s";
    }

    public String getAccessToken(){

        //token未过期使用缓存的token
        long currentTiem = new Date().getSeconds();
        if(accessToken==null||((currentTiem-createTime)>=expires)){
            String res = HttpUtils.sendSSLGet(String.format(tokenUrl,appid,appsecret));
            JSONObject json = JSONObject.parseObject(res);
            int code = json.getInteger("code");
            if(code==0){
                createTime = new Date().getSeconds();
                expires = json.getInteger("expires_in");
                accessToken=json.getString("access_token");
            }else{
                accessToken= null;
                createTime =0;
                expires = 0;
                log.error("获取diy经销商接口报错，错误代码："+code+"，信息："+json.getString("msg"));
                throw new BusinessException("获取diy经销商接口报错，错误代码："+code+"，信息："+json.getString("msg"));
            }

        }
        return accessToken;

    }


    public String getUrl(UrlType type){
        String token = getAccessToken();
        String url ="";
        switch (type) {
            case MANAGER:
                url = String.format(managerListUrl,token);
                break;
            case STOREGUIDE:
                url = String.format(storeGuideListUrl,token);
                break;
        }
        return url;
    }



}
