package com.dgtly.wxportal.utils.qywxutils;

import com.alibaba.fastjson.JSONObject;
import com.dgtly.common.exception.BusinessException;
import com.dgtly.wxportal.exception.QyWeixinException;
import com.dgtly.common.utils.http.HttpUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.Date;

/**
 * 企业微信 accessToken相关
 */
@Component
public class QyWxAccessTokenUtil {

    private static final Logger log = LoggerFactory.getLogger(QyWxAccessTokenUtil.class);

    private String accessToken;
    /**
     * 创建时间
     */
    private long createTime;

    /**
     * 过期时间
     */
    private long expires;


    @Value(value = "${qiyeweixin.corpid:none}")
    private String corpid;



    @Value(value = "${qiyeweixin.corpsecret:none}")
    private String corpsecret;

    @Value(value = "${qiyeweixin.agentId:none}")
    private String agentId;



    /**
     * 获取access_token
     * @return
     */
    public String getAccessToken() {
        JSONObject json;
        String url;

        try {
            //token未过期使用缓存的token
            long currentTiem = new Date().getTime();
            if(this.accessToken!=null &&(currentTiem-createTime)<(expires*1000)){
                log.info("本身的token为{}",this.accessToken);
                return this.accessToken;
            }
            //获取请求地址
            url = QyWxServiceUrl.ACCESS_TOKEN_URL.getformatUrl(corpid, corpsecret);
            json = JSONObject.parseObject(HttpUtils.sendGet(url));
        }catch (Exception e){
            this.accessToken=null;
            log.error("获取企业微信accesstoken错误",e);
            throw e;
        }
        Integer errcode = json.getInteger("errcode");
        if(errcode!=0){
            this.accessToken=null;
            throw new QyWeixinException(errcode,url);
        }
        String token = json.getString("access_token");
        long expires = json.getLong("expires_in");
        this.createTime = new Date().getTime();
        this.accessToken = token;
        this.expires = expires;
        log.info("请求获得的token为{}",token);
        return token;
    }

    public String getCorpid() {
        return corpid;
    }


    public String getCorpsecret() {
        return corpsecret;
    }

    public String getAgentId() {
        return agentId;
    }

    public void setAgentId(String agentId) {
        this.agentId = agentId;
    }

}
