package com.dgtly.wxportal.utils.qywxutils;


import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.dgtly.common.utils.http.HttpUtils;
import com.dgtly.system.service.ISysConfigService;
import com.dgtly.system.service.ISysUserService;
import com.dgtly.system.service.impl.SysConfigServiceImpl;
import com.dgtly.system.service.impl.SysUserServiceImpl;
import com.dgtly.wxportal.domain.WxSendMessage;
import com.dgtly.wxportal.exception.QyWeixinException;
import com.dgtly.wxportal.mapper.WxSendMessageMapper;
import com.dgtly.wxportal.service.IWxSendMessageService;
import com.dgtly.wxportal.utils.qywxutils.messageModel.QyWxBaseMessage;
import com.dgtly.wxportal.utils.qywxutils.messageModel.QyWxTextMessage;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 企业微信发送信息工具类
 */
@Component
public class QyWxSendMessageUtil {
    private static final Logger log = LoggerFactory.getLogger(QyWxSendMessageUtil.class);

    @Autowired
    private QyWxAccessTokenUtil qyWxAccessTokenUtil;


    @Autowired
    private SysConfigServiceImpl configService;
    @Autowired
    private WxSendMessageMapper wxSendMessageMapper;


    public boolean sendMessage(QyWxBaseMessage message){

        message.setAgentid(qyWxAccessTokenUtil.getAgentId());
        String url = QyWxServiceUrl.SEND_MESSAGE_URL.getformatUrl(qyWxAccessTokenUtil.getAccessToken());
        String result =  HttpUtils.sendJsonPost(url,message);
        JSONObject json = JSONObject.parseObject(result);

        Integer errcode = json.getInteger("errcode");
        if(errcode!=0){
            throw new QyWeixinException(errcode,url);
        }
        return true;

    }

    @Async
    public void sendNoticeMessage(Set<String> customerCodes,JSONObject obj, Map<String,Map<String,Object>> maps,String temple){
        List<WxSendMessage> wmList = new ArrayList<>();
        if(customerCodes.size()>0){
            for(String code:customerCodes){
                if(maps.containsKey(code)&&maps.get(code).get("touser")!=null&&!maps.get(code).get("touser").toString().trim().equals("")){
                    WxSendMessage wm= new WxSendMessage();
                    QyWxTextMessage qyWxTextMessage = new QyWxTextMessage();
                    qyWxTextMessage.setTouser(maps.get(code).get("touser").toString());
                    wm.setToUser(qyWxTextMessage.getTouser());
                    String str = obj.getString(code).split(",").length+"";
                    String text = String.format(temple,str,code);
                    qyWxTextMessage.setText(text);
                    wm.setSendText(qyWxTextMessage.getText().getContent());
                    try{
                        sendMessage(qyWxTextMessage);
                        wm.setIsSuccess("1");
                    }catch (Exception e){
                        log.error("对"+maps.get(code).get("touser")+"发送消息失败",e);
                    }finally {
                        wmList.add(wm);
                    }
                }else{
                    log.error("经销商code为："+code+"的经销商未发现相应人员！！");
                }
            }
        }
        if(wmList.size()>0){
            try{
                wxSendMessageMapper.bathInsertWxSendMessage(wmList);
            }catch (Exception e){

                log.error("发送微信信息时插入记录出错！！",e);
            }


        }


    }
}
